# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/zing_internal/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\ZingInternal\\": "packages/litecms/zing_internal/src",
            "Litecms\\ZingInternal\\Seeders\\": "packages/litecms/zing_internal/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\ZingInternal\Providers\ZingInternalServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'ZingInternal'  => Litecms\ZingInternal\Facades\ZingInternal::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\ZingInternal\\Seeders\\ZingInternalTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\ZingInternal\Providers\ZingInternalServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\ZingInternal\Providers\ZingInternalServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\ZingInternal\Providers\ZingInternalServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/zing_internal/{modulename}

**User**

    http://path-to-route-folder/user/zing_internal/{modulename}

**Public**

    http://path-to-route-folder/zing_internals


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/zing_internal/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/zing_internal/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/zing_internal/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/zing_internal/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/zing_internal/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/zing_internal/{modulename}/{slug}
    METHOD: GET